﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using DontHarmDesktop.Models;

namespace DontHarmDesktop
{
    class AuthState
    {
        /// <summary>
        /// Заблокирован ли логин
        /// </summary>
        public static bool LoginBlocked { get; set; } = false;

        /// <summary>
        /// До какого момента заблокирован логин
        /// </summary>
        public static DateTime? LoginBlockedUntil { get; set; } = null;

        /// <summary>
        /// Сколько раз логин провален
        /// </summary>
        public static int AttemptsFailed { get; set; } = 0;

        /// <summary>
        /// Текущий пользователь
        /// </summary>
        public static Models.users CurrentUser { get; set; } = null;

        /// <summary>
        /// Время начала сеанса
        /// </summary>
        public static DateTime SessionStart { get; set; }

        /// <summary>
        /// Ограничен ли по времени сеанс
        /// </summary>
        public static bool SessionIsLimited { get; set; } = false;

        /// <summary>
        /// Планируемое время завершения сеанса
        /// </summary>
        public static DateTime SessionEnd { get; set;}

        /// <summary>
        /// Блокирует вход в приложение
        /// </summary>
        public static void BlockLogin(TimeSpan timeSpan)
        {
            DateTime targetTime = DateTime.Now + timeSpan;
            if (LoginBlockedUntil == null || LoginBlockedUntil < targetTime)
            {
                // Если время снятия блокировки больше чем установим сейчас или
                // совсем не установлено, устанавливаем на заданное
                LoginBlockedUntil = targetTime;
                LoginBlocked = true;
            }
        }
    }
}
