﻿using DontHarmDesktop.Pages;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Threading;

namespace DontHarmDesktop
{
    /// <summary>
    /// Логика взаимодействия для MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        /// <summary>
        /// Таймер принуждённого выхода из приложения
        /// </summary>
        DispatcherTimer logoutTimer = new DispatcherTimer();

        public DispatcherTimer LogoutTimer { get {
                return logoutTimer;
            } 
            set {
                logoutTimer = value;
            }
        }

        /// <summary>
        /// Было ли показано предупреждение о скором выходе из системы
        /// </summary>
        bool shownLogoutWarning = false;

        public MainWindow()
        {
            InitializeComponent();
            DataContext = new ViewModels.MainViewModel();
            logoutTimer.Tick += LogoutTimerTick;
        }

        /// <summary>
        /// Запускает таймер выхода
        /// </summary>
        public void StartLogoffTimer()
        {
            shownLogoutWarning = false;
            logoutTimer.Interval = new TimeSpan(0, 0, 5);
            logoutTimer.Start();
        }

        /// <summary>
        /// callback таймера принудительного выхода
        /// </summary>
        private void LogoutTimerTick(object sender, EventArgs e)
        {
            // Проверяем закончилось ли время
            // Проверку роли не выполняем, т.к. таймер даже не начинается если роль не подходит
            if (DateTime.Now > AuthState.SessionEnd)
            {
                // Сессия закончилась, блокируем вход на 2 минуты
                AuthState.BlockLogin(TimeSpan.FromMinutes(2));

                // Останавливаем таймер
                logoutTimer.Stop();

                // Сбрасываем пользователя
                AuthState.CurrentUser = null;

                // Отражаем это всё в UI
                MainFrame.Navigate(new AuthPage());
                TimerTextBlock.Text = String.Empty;
                
                return;
            }

            // Вычисление остатка времени
            var timeDiff = AuthState.SessionEnd - DateTime.Now;

            if (!shownLogoutWarning && timeDiff.TotalMinutes < 1)
            {
                MessageBox.Show("Скоро будет произведено кварцевание! Выход из приложения через 1 минуту");
                shownLogoutWarning = true;
            }
            TimerTextBlock.Text = "Минут до кварцевания: " + Math.Round(timeDiff.TotalMinutes, 0);
        }
    }
}
