﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Prism.Mvvm;
using Prism.Commands;
using System.Windows;
using System.Runtime.Remoting.Contexts;
using DontHarmDesktop.Models;

namespace DontHarmDesktop.ViewModels
{
    class AuthViewModel : BindableBase
    {
        public DelegateCommand LoginCmd { get; set; }
        public string Login { get; set; }
        public string Password { get; set; }

        public AuthViewModel() 
        {
            LoginCmd = new DelegateCommand(LoginExec);
        }

        private void LoginExec()
        {
            if (AuthState.LoginBlocked)
            {
                if (DateTime.Now < AuthState.LoginBlockedUntil)
                {
                    // Вход всё ещё заблокирован
                    MessageBox.Show("Вход заблокирован до " + AuthState.LoginBlockedUntil);
                    AddLoginRecord(false, Login);
                    return;
                }

                // Вход уже не заблокирован, можем идти дальше
                AuthState.LoginBlocked = false;
                AuthState.LoginBlockedUntil = null;
            }

            // Пытаемся войти в приложение
            var db = new Models.Entities();
            var result = db.users.FirstOrDefault(p => p.login == Login && p.password == Password);
            if (result == null)
            {
                MessageBox.Show("Логин или пароль не совпадают");
                AuthState.AttemptsFailed++;
                if (AuthState.AttemptsFailed > 1)
                {
                    // Количество попыток превышено, блокировка входа на 10 секунд
                    AuthState.BlockLogin(TimeSpan.FromSeconds(10));
                }
                AddLoginRecord(false, Login);
                return;
            }

            // Вход успешен, устанавливаем параметры AuthState
            AuthState.AttemptsFailed    = 0;
            AuthState.CurrentUser       = result;
            AuthState.SessionStart      = DateTime.Now;
            AuthState.SessionIsLimited  = false;

            // Если роль пользователя - лаборант, надо запустить таймер кварцевания
            // на 2 минуты
            if (result.role == 2)
            {
                AuthState.SessionEnd = AuthState.SessionStart + TimeSpan.FromMinutes(2);
                AuthState.SessionIsLimited = true;
                (App.Current.MainWindow as MainWindow).StartLogoffTimer();
            }

            (App.Current.MainWindow as MainWindow).MainFrame.Navigate(new Pages.WelcomePage());
            AddLoginRecord(true, Login);
        }

        /// <summary>
        /// Добавляет в БД попытку входа в приложение
        /// </summary>
        private void AddLoginRecord(bool successful, string login)
        {
            var record = new login_attempts();
            record.successfull = Convert.ToByte(successful);
            record.login = login;
            record.ip_address = "127.0.0.1";
            record.created_at = DateTime.Now;

            var db = new Models.Entities();
            db.login_attempts.Add(record);
            db.SaveChanges();
        }
    }
}
